<?xml version="1.0" ?><!DOCTYPE TS><TS language="bo" sourcelanguage="en" version="2.1">
<context>
    <name>Bubble</name>
    <message>
        <location filename="../dde-osd/notification/bubble.cpp" line="309"/>
        <source>1 new message</source>
        <translation>འཕྲིན་གསར་1 </translation>
    </message>
</context>
<context>
    <name>BubbleItem</name>
    <message>
        <location filename="../dde-osd/notification-center/bubbleitem.cpp" line="221"/>
        <source>Just Now</source>
        <translation>ད་གིན།</translation>
    </message>
    <message>
        <location filename="../dde-osd/notification-center/bubbleitem.cpp" line="223"/>
        <source>%1 minutes ago</source>
        <translation>སྐར་མ་%1གོང་ལ།  </translation>
    </message>
    <message>
        <location filename="../dde-osd/notification-center/bubbleitem.cpp" line="225"/>
        <source>%1 hours ago</source>
        <translation>ཆུ་ཚོད་%1གོང་ལ།  </translation>
    </message>
    <message>
        <location filename="../dde-osd/notification-center/bubbleitem.cpp" line="228"/>
        <source>Yesterday </source>
        <translation>ཁ་སང་།</translation>
    </message>
</context>
<context>
    <name>Content</name>
    <message>
        <location filename="../dde-license-dialog/content.cpp" line="228"/>
        <source>Cancel</source>
        <translation>ཕྱིར་འཐེན།</translation>
    </message>
    <message>
        <location filename="../dde-license-dialog/content.cpp" line="229"/>
        <source>Confirm</source>
        <translation>གཏན་ཁེལ། </translation>
    </message>
</context>
<context>
    <name>ContentWidget</name>
    <message>
        <location filename="../dde-shutdown/view/contentwidget.cpp" line="330"/>
        <location filename="../dde-shutdown/view/contentwidget.cpp" line="367"/>
        <location filename="../dde-shutdown/view/contentwidget.cpp" line="391"/>
        <location filename="../dde-shutdown/view/contentwidget.cpp" line="527"/>
        <source>Shut down</source>
        <translation>ཁ་བརྒྱབ།</translation>
    </message>
    <message>
        <location filename="../dde-shutdown/view/contentwidget.cpp" line="332"/>
        <location filename="../dde-shutdown/view/contentwidget.cpp" line="369"/>
        <location filename="../dde-shutdown/view/contentwidget.cpp" line="396"/>
        <location filename="../dde-shutdown/view/contentwidget.cpp" line="530"/>
        <source>Reboot</source>
        <translation>བསྐྱར་སློང་།</translation>
    </message>
    <message>
        <location filename="../dde-shutdown/view/contentwidget.cpp" line="392"/>
        <source>Are you sure you want to shut down?</source>
        <translation>ཁྱོད་ཀྱི་ཁ་རྒྱག་རྒྱུ་གཏན་ཁེལ་ལམ།</translation>
    </message>
    <message>
        <location filename="../dde-shutdown/view/contentwidget.cpp" line="397"/>
        <source>Are you sure you want to reboot?</source>
        <translation>ཁྱོད་ཀྱི་བསྐྱར་སློང་བྱེད་རྒྱུ་གཏན་ཁེལ་ལམ།</translation>
    </message>
    <message>
        <location filename="../dde-shutdown/view/contentwidget.cpp" line="338"/>
        <location filename="../dde-shutdown/view/contentwidget.cpp" line="401"/>
        <location filename="../dde-shutdown/view/contentwidget.cpp" line="542"/>
        <source>Log out</source>
        <translation>ཐོ་སུབ་པ།</translation>
    </message>
    <message>
        <location filename="../dde-shutdown/view/contentwidget.cpp" line="402"/>
        <source>Are you sure you want to log out?</source>
        <translation>ཁྱོད་ཀྱི་ཐོ་འདོར་རྒྱུ་གཏན་ཁེལ་ལམ།</translation>
    </message>
    <message>
        <location filename="../dde-shutdown/view/contentwidget.cpp" line="334"/>
        <location filename="../dde-shutdown/view/contentwidget.cpp" line="533"/>
        <source>Suspend</source>
        <translation>སྒུག་སྡོད།</translation>
    </message>
    <message>
        <location filename="../dde-shutdown/view/contentwidget.cpp" line="326"/>
        <source>The programs are preventing the computer from shutting down / hibernation, and forcing shut down / hibernate may cause data loss.</source>
        <translation>གོང་གི་བྱ་རིམ་ཁ་བརྒྱབ་པ་/མལ་གསོ་བར་བཀག་འགོག་བྱེད་པ་དང་། བཙན་ཤེད་ཀྱིས་ཁ་བརྒྱབ་པ་/མལ་གསོ་རུ་བཅུག་པ་བཅས་བྱས་ཚེ། གཞི་གྲངས་བརླག་སྲིད།</translation>
    </message>
    <message>
        <location filename="../dde-shutdown/view/contentwidget.cpp" line="327"/>
        <source>To close the program, Click Cancel, and then close the program.</source>
        <translation>ཁྱོད་ཀྱིས་“འདོར་བ་”ཞེས་པ་མནན་ནས་བྱ་རིམ་འདི་དག་ཁ་བརྒྱབ་ཆོག </translation>
    </message>
    <message>
        <location filename="../dde-shutdown/view/contentwidget.cpp" line="336"/>
        <location filename="../dde-shutdown/view/contentwidget.cpp" line="536"/>
        <source>Hibernate</source>
        <translation>མལ་གསོ།</translation>
    </message>
    <message>
        <location filename="../dde-shutdown/view/contentwidget.cpp" line="539"/>
        <source>Lock</source>
        <translation>ཟྭ་རྒྱག</translation>
    </message>
    <message>
        <location filename="../dde-shutdown/view/contentwidget.cpp" line="546"/>
        <source>Switch user</source>
        <translation>སྤྱོད་མཁན་བརྗེ་བ།</translation>
    </message>
</context>
<context>
    <name>DMemoryWarningDialog</name>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="49"/>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="86"/>
        <source>Cancel</source>
        <translation>ཕྱིར་འཐེན།</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="51"/>
        <source>Release</source>
        <translation>གློད་གྲོལ།</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="54"/>
        <source>This application will be ended, please make sure your data has been saved!</source>
        <translation>ཉེར་སྤྱོད་ནང་གསོག་གློད་གྲོལ་བྱེད་རྒྱུ་ཡིན་པས། མིག་སྔའི་གཞི་གྲངས་དག་ཉར་ཚགས་བྱས་ཡོད་མེད་གཏན་འཁེལ་བྱོས།</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="55"/>
        <source>Please save your document, text and spreadsheet</source>
        <translation>དཔེར་ན་ཡིག་ཆ་དང་། ཡིག་རྐྱང་། རེའུ་མིག་སོགས་ཀྱི་གཞི་གྲངས། </translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="87"/>
        <source>Continue</source>
        <translation>མུ་མཐུད།</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="105"/>
        <source>Insufficient system memory, please end some applications to avoid getting stuck.</source>
        <translation>མིག་སྔའི་རྒྱུད་ཁོངས་ཀྱི་ནང་གསོག་མི་འདང་བས། མི་འགག་པའི་ཆེད་འབྲེལ་ཡོད་ཀྱི་ཉེར་སྤྱོད་ནང་གསོག་གློད་གྲོལ་བྱེད།</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="217"/>
        <source>Continue to run %1, %2MB memory is required</source>
        <translation>གལ་ཏེ་ཉེར་སྤྱོད་%1མུ་མཐུད་འཁོར་སྐྱོད་བྱེད་དགོས་ན། ནང་གསོག་%2MBགློད་གྲོལ་བྱེད་དགོས།</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="220"/>
        <source>Continue to open browser tab, %1MB memory is required</source>
        <translation>གལ་ཏེ་བཤར་ཆས་མུ་མཐུད་ཁ་ཕྱེ་དགོས་ཚེ། ནང་གསོག་%1MBགློད་གྲོལ་བྱེད་དགོས།</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="223"/>
        <source>To continue the operation, %1MB memory is required</source>
        <translation>གལ་ཏེ་བཀའ་རྒྱ་མུ་མཐུད་ལག་ལེན་བསྟར་དགོས་ཚེ། ནང་གསོག་%1MBགློད་གྲོལ་བྱེད་དགོས།</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="229"/>
        <source>Your current memory is sufficient enough, continue to run %1?</source>
        <translation>ཁྱོད་ཀྱི་མིག་སྔའི་ནང་གསོག་འདང་ངེས་འདུག་པས། ཉེར་སྤྱོད་%1མུ་མཐུད་འཁོར་སྐྱོད་བྱེད་དགོས་སམ།</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="232"/>
        <source>Your current memory is sufficient enough, continue to open browser tab?</source>
        <translation>ཁྱོད་ཀྱི་མིག་སྔའི་ནང་གསོག་འདང་ངེས་འདུག་པས། བཤར་ཆས་མུ་མཐུད་ཁ་ཕྱེ་དགོས་སམ།</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="235"/>
        <source>Your current memory is sufficient enough, continue the operation?</source>
        <translation>ཁྱོད་ཀྱི་མིག་སྔའི་ནང་གསོག་འདང་ངེས་འདུག་པས། བཀའ་རྒྱ་མུ་མཐུད་ལག་ལེན་བསྟར་དགོས་སམ།</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dde-offline-upgrader/dialog.cpp" line="30"/>
        <source>Updates downloaded, restart to update?</source>
        <translation>གསར་བརྗེ་ཕབ་ལེན་བྱས་ཟིན། འགོ་བསྐྱར་སློང་བྱས་ནས་གསར་བརྗེ་ལེགས་གྲུབ་བྱེད་དགོས་པས། གསར་བརྗེ་བྱེད་དགོས་སམ།</translation>
    </message>
    <message>
        <location filename="../dde-offline-upgrader/dialog.cpp" line="33"/>
        <source>Remind Later</source>
        <translation>ཏོག་ཙམ་ནས་དྲན་སྐུལ་བྱེད།</translation>
    </message>
    <message>
        <location filename="../dde-offline-upgrader/dialog.cpp" line="34"/>
        <source>Not Now</source>
        <translation>གནས་སྐབས་གསར་པ་མི་བརྗེ།</translation>
    </message>
    <message>
        <location filename="../dde-offline-upgrader/dialog.cpp" line="35"/>
        <source>Update Now</source>
        <translation>ལམ་སེང་གསར་སྒྱུར་བྱེད།</translation>
    </message>
</context>
<context>
    <name>DisplayModeProvider</name>
    <message>
        <location filename="../dde-osd/displaymodeprovider.cpp" line="249"/>
        <source>Only on %1</source>
        <translation>བརྙན་ཡོལ་%1</translation>
    </message>
    <message>
        <location filename="../dde-osd/displaymodeprovider.cpp" line="251"/>
        <source>Duplicate</source>
        <translation>པར་སློག</translation>
    </message>
    <message>
        <location filename="../dde-osd/displaymodeprovider.cpp" line="253"/>
        <source>Extend</source>
        <translation>རྒྱ་སྐྱེད།</translation>
    </message>
</context>
<context>
    <name>Frame</name>
    <message>
        <location filename="../dde-offline-upgrader/frame.cpp" line="54"/>
        <source>Please don&apos;t power off or unplug your machine</source>
        <translation>གློག་ཁུངས་བཀོག་པའམ་ཨུ་ཚུགས་ཀྱིས་ཁ་མ་རྒྱོབ།</translation>
    </message>
    <message>
        <location filename="../dde-offline-upgrader/frame.cpp" line="136"/>
        <source>Installing updates %1%, please wait...</source>
        <translation>སྒྲིག་འཇུག་གསར་བརྗེ་བྱེད་བཞིན་ཡོད་པས་%1%། ཏོག་ཙམ་སྒུག་རོགས།</translation>
    </message>
</context>
<context>
    <name>GreeterWorkek</name>
    <message>
        <location filename="../lightdm-deepin-greeter/greeterworkek.cpp" line="93"/>
        <source>Domain account</source>
        <translation>ཁོངས་ཀྱི་རྩིས་ཁྲ།</translation>
    </message>
    <message>
        <location filename="../lightdm-deepin-greeter/greeterworkek.cpp" line="249"/>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>མཛུབ་རིས་གསང་ཨང་ར་སྤྲོད་བྱེད་པ་དུས་ཚོད་ལས་ཡོལ་ཟིན་པས། ལག་ཐབས་ཀྱིས་ནང་འཇུག་བྱེད་རོགས།</translation>
    </message>
    <message>
        <location filename="../lightdm-deepin-greeter/greeterworkek.cpp" line="264"/>
        <source>Failed to match fingerprint</source>
        <translation>མཛུབ་རིས་ཀྱིས་སྒོ་ལྕགས་ཕྱེ་ཐུབ་མ་སོང་།</translation>
    </message>
    <message>
        <location filename="../lightdm-deepin-greeter/greeterworkek.cpp" line="282"/>
        <source>Wrong Password</source>
        <translation>གསང་ཨང་ནོར་འདུག</translation>
    </message>
    <message>
        <location filename="../lightdm-deepin-greeter/greeterworkek.cpp" line="287"/>
        <source>The domain account or password is not correct. Please enter again.</source>
        <translation>ཁོངས་ཀྱི་རྩིས་ཁྲའམ་ཁོངས་ཀྱི་གསང་ཨང་ནོར་འདུག་པས། ཡང་བསྐྱར་ནང་འཇུག་བྱོས།</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <location filename="../dde-shutdown/view/inhibitwarnview.cpp" line="66"/>
        <source>Cancel</source>
        <translation>ཕྱིར་འཐེན།</translation>
    </message>
</context>
<context>
    <name>KBLayoutIndicator</name>
    <message>
        <location filename="../dde-osd/kblayoutindicator.cpp" line="161"/>
        <source>Add keyboard layout</source>
        <translation>མཐེབ་གཞོང་བཀོད་པ་སྣོན་པ།</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <location filename="../dde-lock/lockworker.cpp" line="98"/>
        <source>Domain account</source>
        <translation>ཁོངས་ཀྱི་རྩིས་ཁྲ།</translation>
    </message>
    <message>
        <location filename="../dde-lock/lockworker.cpp" line="221"/>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>མཛུབ་རིས་གསང་ཨང་ར་སྤྲོད་བྱེད་པ་དུས་ཚོད་ལས་ཡོལ་ཟིན་པས། ལག་ཐབས་ཀྱིས་ནང་འཇུག་བྱེད་རོགས།</translation>
    </message>
    <message>
        <location filename="../dde-lock/lockworker.cpp" line="239"/>
        <source>Failed to match fingerprint</source>
        <translation>མཛུབ་རིས་ཀྱིས་སྒོ་ལྕགས་ཕྱེ་ཐུབ་མ་སོང་།</translation>
    </message>
    <message>
        <location filename="../dde-lock/lockworker.cpp" line="274"/>
        <source>Wrong Password</source>
        <translation>གསང་ཨང་ནོར་འདུག</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <location filename="../dde-shutdown/view/multiuserswarningview.cpp" line="44"/>
        <source>Cancel</source>
        <translation>ཕྱིར་འཐེན།</translation>
    </message>
    <message>
        <location filename="../dde-shutdown/view/multiuserswarningview.cpp" line="129"/>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>གློག་ཀླད་འདིའི་སྟེང་ད་དུང་གོང་གི་རྩིས་ཁྲ་དག་ཐོ་འཇུག་བྱས་ཡོད། གློག་ཀླད་བསྐྱར་སློང་བྱས་ཚེ་གཞི་གྲངས་བརླག་སྲིད་པས། གློག་ཀླད་འདི་བསྐྱར་སློང་བྱ་དགོས་སམ།</translation>
    </message>
    <message>
        <location filename="../dde-shutdown/view/multiuserswarningview.cpp" line="123"/>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>གློག་ཀླད་འདིའི་སྟེང་ད་དུང་གོང་གི་རྩིས་ཁྲ་དག་ཐོ་འཇུག་བྱས་ཡོད། གློག་ཀླད་ཁ་བརྒྱབ་ཚེ་གཞི་གྲངས་བརླག་སྲིད་པས། གློག་ཀླད་འདི་ཁ་རྒྱག་དགོས་སམ།</translation>
    </message>
</context>
<context>
    <name>NetworkSecretDialog</name>
    <message>
        <location filename="../dnetwork-secret-dialog/networksecretdialog.cpp" line="46"/>
        <location filename="../dnetwork-secret-dialog/networksecretdialog.cpp" line="52"/>
        <location filename="../dnetwork-secret-dialog/networksecretdialog.cpp" line="62"/>
        <source>Password</source>
        <translation>གསང་ཨང་། </translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/networksecretdialog.cpp" line="47"/>
        <location filename="../dnetwork-secret-dialog/networksecretdialog.cpp" line="48"/>
        <location filename="../dnetwork-secret-dialog/networksecretdialog.cpp" line="49"/>
        <source>Key</source>
        <translation>གསང་ལྡེ།</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/networksecretdialog.cpp" line="50"/>
        <source>key</source>
        <translation>གསང་ལྡེ།</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/networksecretdialog.cpp" line="58"/>
        <source>Private Pwd</source>
        <translation>སྒེར་ལྡེའི་གསང་ཨང་།</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/networksecretdialog.cpp" line="61"/>
        <source>Proxy Password</source>
        <translation>ལས་ཚབ་གསང་ཨང་།</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/networksecretdialog.cpp" line="63"/>
        <source>Group Password</source>
        <translation>ཚོ་པའི་གསང་ཨང་།</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/networksecretdialog.cpp" line="105"/>
        <source>Password required to connect &lt;font color=&quot;%1&quot;&gt;%2&lt;/font&gt;</source>
        <translation>&lt;font color=&quot;%1&quot;&gt;དང་%2&lt;/font&gt;མཐུད་པར་གསང་ཨང་དགོས།</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/networksecretdialog.cpp" line="174"/>
        <source>Wrong password, please enter again!</source>
        <translation>གསང་ཨང་ནོར་འདུག་པས། ཡང་བསྐྱར་ནང་འཇུག་བྱོས།</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/networksecretdialog.cpp" line="114"/>
        <source>Cancel</source>
        <translation>ཕྱིར་འཐེན།</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/networksecretdialog.cpp" line="114"/>
        <source>Connect</source>
        <translation>འབྲེལ་མཐུད། </translation>
    </message>
</context>
<context>
    <name>NotificationsPlugin</name>
    <message>
        <location filename="../dde-notification-plugin/notifications/notificationsplugin.cpp" line="71"/>
        <source>Notification Center</source>
        <translation>བརྡ་ཐོའི་ལྟེ་གནས།</translation>
    </message>
    <message>
        <location filename="../dde-notification-plugin/notifications/notificationsplugin.cpp" line="91"/>
        <source>%1 Notifications</source>
        <translation>བརྡ་ཐོ་%1</translation>
    </message>
    <message>
        <location filename="../dde-notification-plugin/notifications/notificationsplugin.cpp" line="93"/>
        <source>No messages</source>
        <translation>བརྡ་འཕྲིན་གསར་པ་མི་འདུག</translation>
    </message>
    <message>
        <location filename="../dde-notification-plugin/notifications/notificationsplugin.cpp" line="239"/>
        <source>Turn off DND mode</source>
        <translation>སུན་འགོག་དཔེ་རྣམ་ཁ་རྒྱོབ།</translation>
    </message>
    <message>
        <location filename="../dde-notification-plugin/notifications/notificationsplugin.cpp" line="239"/>
        <source>Turn on DND mode</source>
        <translation>སུན་འགོག་དཔེ་རྣམ་ཁ་ཕྱེ།</translation>
    </message>
    <message>
        <location filename="../dde-notification-plugin/notifications/notificationsplugin.cpp" line="246"/>
        <source>Notification settings</source>
        <translation>བརྡ་ཐོ་སྒྲིག་འགོད།</translation>
    </message>
</context>
<context>
    <name>NotifyCenterWidget</name>
    <message>
        <location filename="../dde-osd/notification-center/notifycenterwidget.cpp" line="89"/>
        <source>Notification Center</source>
        <translation>བརྡ་ཐོའི་ལྟེ་གནས།</translation>
    </message>
</context>
<context>
    <name>NotifyWidget</name>
    <message>
        <location filename="../dde-osd/notification-center/notifywidget.cpp" line="40"/>
        <source>No system notifications</source>
        <translation>རྒྱུད་ཁོངས་ཀྱི་བརྡ་ཐོ་མེད།</translation>
    </message>
</context>
<context>
    <name>OSDProvider</name>
    <message>
        <location filename="../dde-osd/osdprovider.cpp" line="47"/>
        <source>Window effect enabled</source>
        <translation>སྒེའུ་ཁུང་གི་དམིགས་བསལ་ནུས་པ་ཁ་ཕྱེ་བ།</translation>
    </message>
    <message>
        <location filename="../dde-osd/osdprovider.cpp" line="48"/>
        <source>Window effect disabled</source>
        <translation>སྒེའུ་ཁུང་གི་དམིགས་བསལ་ནུས་པ་ཁ་བརྒྱབ་ཟིན།</translation>
    </message>
    <message>
        <location filename="../dde-osd/osdprovider.cpp" line="49"/>
        <source>Failed to enable window effects</source>
        <translation>སྒེའུ་ཁུང་གི་དམིགས་བསལ་ནུས་པ་ཁ་འབྱེད་ཐབས་བྲལ།</translation>
    </message>
</context>
<context>
    <name>PinCodeDialog</name>
    <message>
        <location filename="../dde-bluetooth-dialog/pincodedialog.cpp" line="39"/>
        <source>The PIN for connecting to the Bluetooth device is:</source>
        <translation>སོ་སྔོན་སྒྲིག་ཆས་ཀྱི་PINདང་མཐུད་པ།</translation>
    </message>
    <message>
        <location filename="../dde-bluetooth-dialog/pincodedialog.cpp" line="47"/>
        <source>Cancel</source>
        <translation>འདོར་བ། </translation>
    </message>
    <message>
        <location filename="../dde-bluetooth-dialog/pincodedialog.cpp" line="49"/>
        <source>Confirm</source>
        <translation>གཏན་ཁེལ། </translation>
    </message>
</context>
<context>
    <name>ProcessInfoModel</name>
    <message>
        <location filename="../dmemory-warning-dialog/src/processinfomodel.cpp" line="111"/>
        <source>End</source>
        <translation>གློད་གྲོལ།</translation>
    </message>
</context>
<context>
    <name>SuspendDialog</name>
    <message>
        <location filename="../dde-suspend-dialog/suspenddialog.cpp" line="39"/>
        <source>External monitor detected, suspend?</source>
        <translation>ཕྱི་རོལ་གྱི་མངོན་ཆས་དཔྱད་འཇལ་ཐུབ་པས། སྒུག་སྡོད་དགོས་སམ།</translation>
    </message>
    <message>
        <location filename="../dde-suspend-dialog/suspenddialog.cpp" line="39"/>
        <location filename="../dde-suspend-dialog/suspenddialog.cpp" line="61"/>
        <source>%1s</source>
        <translation>སྐར་ཆ་%1</translation>
    </message>
    <message>
        <location filename="../dde-suspend-dialog/suspenddialog.cpp" line="50"/>
        <source>Cancel</source>
        <translation>ཕྱིར་འཐེན།</translation>
    </message>
    <message>
        <location filename="../dde-suspend-dialog/suspenddialog.cpp" line="50"/>
        <source>Suspend</source>
        <translation>སྒུག་སྡོད།</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <location filename="../dde-shutdown/view/systemmonitor.cpp" line="45"/>
        <source>Start system monitor</source>
        <translation>རྒྱུད་ཁོངས་ཀྱི་ལྟ་ཆས་འགོ་སློང་།</translation>
    </message>
</context>
<context>
    <name>TimeWidget</name>
    <message>
        <location filename="../dde-lock/timewidget.cpp" line="69"/>
        <source>hh:mm</source>
        <translation>hh:mm</translation>
    </message>
    <message>
        <location filename="../dde-lock/timewidget.cpp" line="70"/>
        <source>yyyy-MM-dd dddd</source>
        <translation>yyyy-MM-dd dddd</translation>
    </message>
</context>
<context>
    <name>TouchscreenSetting</name>
    <message>
        <location filename="../dde-touchscreen-dialog/touchscreensetting.cpp" line="43"/>
        <source>Select your touch screen</source>
        <translation>ཐུག་རེག་བརྙན་ཡོལ་གདམ་པ། </translation>
    </message>
    <message>
        <location filename="../dde-touchscreen-dialog/touchscreensetting.cpp" line="53"/>
        <source>Cancel</source>
        <translation>འདོར་བ། </translation>
    </message>
    <message>
        <location filename="../dde-touchscreen-dialog/touchscreensetting.cpp" line="54"/>
        <source>Confirm</source>
        <translation>གཏན་ཁེལ། </translation>
    </message>
</context>
<context>
    <name>UpdateContent</name>
    <message>
        <location filename="../dde-welcome/updatecontent.cpp" line="44"/>
        <source>Welcome, system updated successfully</source>
        <translation>དགའ་བསུ་ཞུ། རྒྱུད་ཁོངས་རིམ་སྤོར་ལེགས་གྲུབ་བྱུང་སོང་།</translation>
    </message>
    <message>
        <location filename="../dde-welcome/updatecontent.cpp" line="45"/>
        <source>Current Edition:</source>
        <translation>མིག་སྔའི་པར་གཞི།</translation>
    </message>
    <message>
        <location filename="../dde-welcome/updatecontent.cpp" line="46"/>
        <source>Enter</source>
        <translation>སྤྱོད་འགོ་ཚུགས།</translation>
    </message>
</context>
<context>
    <name>WMChooser</name>
    <message>
        <location filename="../dde-wm-chooser/wmchooser.cpp" line="57"/>
        <source>Effect Mode</source>
        <translation>དཔེ་རྣམ་དམིགས་བསལ།</translation>
    </message>
    <message>
        <location filename="../dde-wm-chooser/wmchooser.cpp" line="60"/>
        <source>Normal Mode</source>
        <translation>དཔེ་རྣམ་དཀྱུས་མ།</translation>
    </message>
    <message>
        <location filename="../dde-wm-chooser/wmchooser.cpp" line="68"/>
        <source>It has detected that you are using a virtual machine, which will affect the system performance and operation experience, for a smooth experience, Normal Mode is recommended</source>
        <translation>ཁྱོད་ཀྱིས་རྟོག་བཟོའི་འཕྲུལ་འཁོར་སྤྱོད་བཞིན་འདུག་པས། འདིས་རྒྱུད་ཁོངས་ཀྱི་ནུས་པ་དང་བཀོལ་སྤྱོད་མྱོང་རོལ་ལ་ཤུགས་རྐྱེན་ཐེབས་ཀྱི་ཡོད། རྟོག་བཟོའི་འཕྲུལ་འཁོར་ནང་རྒྱུད་ཁོངས་འདི་ཉིད་བདེ་བླག་ངང་སྤྱོད་ཐུབ་ཆེད། ཁྱོད་ཀྱིས་སྤྱིར་བཏང་གི་དཔེ་རྣམ་བདམས་ནས་ཅོག་ངོས་སུ་འཛུལ་རྒྱུའི་གྲོས་འདོན་རྒྱུ་ཡིན།</translation>
    </message>
    <message>
        <location filename="../dde-wm-chooser/wmchooser.cpp" line="71"/>
        <source>Effect Mode: Have a delicate experience. Normal Mode: Enjoy the fast performance</source>
        <translation>དམིགས་བསལ་ནུས་པའི་དཔེ་རྣམ། སྤུས་དག་ཅིང་ལྟ་ན་སྡུག་པ་ཉམས་སུ་མྱོང་བ། སྤྱིར་བཏང་གི་དཔེ་རྣམ། བདེ་བླག་མྱུར་མགྱོགས་ཀྱི་ནུས་པ་ཉམས་སུ་མྱོང་བ།</translation>
    </message>
    <message>
        <location filename="../dde-wm-chooser/wmchooser.cpp" line="64"/>
        <source>Friendly Reminder</source>
        <translation>མཛའ་བརྩེའི་དྲན་སྐུལ།</translation>
    </message>
</context>
<context>
    <name>WarningDialog</name>
    <message>
        <location filename="../dde-warning-dialog/warningdialog.cpp" line="37"/>
        <source>Kindly Reminder</source>
        <translation>ཤ་ཚའི་དྲན་སྐུལ།</translation>
    </message>
    <message>
        <location filename="../dde-warning-dialog/warningdialog.cpp" line="38"/>
        <source>This application cannot run without window effect</source>
        <translation>བཀོལ་སྤྱོད་འདི་ཉིད་སྒེའུ་ཁུང་གི་དམིགས་བསལ་ནུས་པ་མེད་པའི་འོག་འཁོར་སྐྱོད་བྱེད་པར་རྒྱབ་སྐྱོར་མེད།</translation>
    </message>
    <message>
        <location filename="../dde-warning-dialog/warningdialog.cpp" line="42"/>
        <source>OK</source>
        <translation>གཏན་ཁེལ།</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../dde-lowpower/window.cpp" line="39"/>
        <source>Low battery, please plug in</source>
        <translation>གློག་མི་འདང་བས་གློག་ཁུངས་དང་མཐུད་རོགས།</translation>
    </message>
</context>
</TS>